summaryrefslogtreecommitdiff
path: root/src/vm
diff options
context:
space:
mode:
authorVance Morrison <vancem@microsoft.com>2017-04-27 12:43:38 -0700
committerGitHub <noreply@github.com>2017-04-27 12:43:38 -0700
commit8d31b488487a7a3f633ad39d19a684cb1d72a87e (patch)
treea2953f0232d31a9fe6b5f3e575a1632f8b2bc00e /src/vm
parenta07569230a248b5c927ef713863db17ffae44f16 (diff)
downloadcoreclr-8d31b488487a7a3f633ad39d19a684cb1d72a87e.tar.gz
coreclr-8d31b488487a7a3f633ad39d19a684cb1d72a87e.tar.bz2
coreclr-8d31b488487a7a3f633ad39d19a684cb1d72a87e.zip
Turn on unwind information at informational level rather than Info level. (#11257)
This is bascically a bug fix. Quite a while ago we wanted to be able to collect stacks (which needed JIT names, and unwind information) without collecting all verbose CLR events (in particular the GC allocation Tick events). We did this in most places but missed this one.
Diffstat (limited to 'src/vm')
-rw-r--r--src/vm/eventtrace.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/vm/eventtrace.cpp b/src/vm/eventtrace.cpp
index 1eb89385a6..b3ee17e3be 100644
--- a/src/vm/eventtrace.cpp
+++ b/src/vm/eventtrace.cpp
@@ -4465,10 +4465,10 @@ extern "C"
#ifdef _TARGET_AMD64_
// We only do this on amd64 (NOT ARM, because ARM uses frame based stack crawling)
// If we have turned on the JIT keyword to the VERBOSE setting (needed to get JIT names) then
// we assume that we also want good stack traces so we need to publish unwind information so
// ETW can get at it
- if(bIsPublicTraceHandle && ETW_CATEGORY_ENABLED((*context), TRACE_LEVEL_VERBOSE, CLR_RUNDOWNJIT_KEYWORD))
+ if(bIsPublicTraceHandle && ETW_CATEGORY_ENABLED((*context), TRACE_LEVEL_INFORMATION, CLR_RUNDOWNJIT_KEYWORD))
UnwindInfoTable::PublishUnwindInfo(g_fEEStarted != FALSE);
#endif
@@ -4465,10 +4465,10 @@ extern "C"
#ifdef _TARGET_AMD64_
// We only do this on amd64 (NOT ARM, because ARM uses frame based stack crawling)
- // If we have turned on the JIT keyword to the VERBOSE setting (needed to get JIT names) then
+ // If we have turned on the JIT keyword to the INFORMATION setting (needed to get JIT names) then
// we assume that we also want good stack traces so we need to publish unwind information so
// ETW can get at it